library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.STD_LOGIC_ARITH.ALL;
use IEEE.STD_LOGIC_UNSIGNED.ALL;

entity HPLED_driver is
	Port ( 	clkin : in std_logic;
				LED4 : out std_logic;
				Dcommon : out std_logic_vector(10 downto 1);
				Lseg : out std_logic_vector(9 downto 1));
end HPLED_driver;

architecture Behavioral of HPLED_driver is

signal divclk : std_logic;
signal state : integer range 1 to 10;
signal Llatch : std_logic_vector(9 downto 1);

component StateCount
    Port ( clock    : in std_logic;
           stateout : out integer range 1 to 10); 
end component;

component clockdiv is
    Port ( inp : in std_logic;
           oup : out std_logic);
end component;

component DigitDriver is
    Port ( gate : in  STD_LOGIC;
           state : in  integer range 1 to 10;
           drive : out  STD_LOGIC_VECTOR (9 downto 0));
end component;

begin

-- clock divider
inst_clockdiv: clockdiv
port map (
	inp => clkin,
	oup => divclk
);

-- state machine
inst_statecounter: StateCount
port map (
	clock => divclk,
	stateout => state
);

-- Digit drivers
inst_digitdrive: DigitDriver
port map (
	gate => divclk,
	state => state,
	drive => Dcommon
);

-- segment driver
segdrive: process(state)
begin
	case state is
	when 1 =>
		Llatch <= "111111001";
	when 2 =>
		Llatch <= "011000000";
	when 3 =>
		Llatch <= "110110100";
	when 4 =>
		Llatch <= "111100110";
	when 5 =>
		Llatch <= "011001100";
	when 6 =>
		Llatch <= "101101100";
	when 7 =>
		Llatch <= "101111110";
	when 8 =>
		Llatch <= "111000000";
	when 9 =>
		Llatch <= "111111100";
	when 10 =>
		Llatch <= "111101110";
	end case;
end process;

-- For debugging, output signals to LED
LED4 <= Llatch(8);
Lseg <= Llatch;

end Behavioral;

